@@ -569,14 +569,6 @@ QString Generator::fullDocumentLocation(const Node *node)
     return parentName.toLower() + anchorRef;
 }
 
-/*!
-    Generates text for a "see also" list for the given \a node and \a marker
-    if a list has been defined.
-
-    Check for links to the node containing the \sa command, looking for empty
-    ref fields to ensure that a link is referring to the node itself and not
-    a different section of a larger document.
-*/
 void Generator::generateAlsoList(const Node *node, CodeMarker *marker)
 {
     QList<Text> alsoList = node->doc().alsoList();
@@ -591,15 +583,10 @@ void Generator::generateAlsoList(const Node *node, CodeMarker *marker)
         QList<Text> items;
         for (const auto &also : std::as_const(alsoList)) {
             // Every item starts with a link atom.
-            const Atom *atom = also.firstAtom();
-            QString link = atom->string();
+            QString link = also.firstAtom()->string();
             if (!used.contains(link)) {
                 items.append(also);
                 used.insert(link);
-
-                QString ref;
-                if (m_qdb->findNodeForAtom(atom, node, ref) == node && ref.isEmpty())
-                    node->doc().location().warning("Redundant link to self in \\sa command for %1"_L1.arg(node->name()));
             }
         }
 
@@ -743,8 +730,7 @@ void Generator::generateBody(const Node *node, CodeMarker *marker)
                 generateAddendum(node, Invokable, marker);
             if (fn->hasAssociatedProperties())
                 generateAddendum(node, AssociatedProperties, marker);
-            if (fn->hasOverloads() && fn->doc().hasOverloadCommand()
-                && !fn->isSignal() && !fn->isSlot())
+            if (fn->hasOverloads() && fn->doc().hasOverloadCommand())
                 generateAddendum(node, OverloadNote, marker, AdmonitionPrefix::None);
         }
 
@@ -1204,15 +1190,8 @@ void Generator::generateSince(const Node *node, CodeMarker *marker)
 {
     if (!node->since().isEmpty()) {
         Text text;
-        if (node->isSharedCommentNode()) {
-            const auto &collective = static_cast<const SharedCommentNode *>(node)->collective();
-            QString typeStr = collective.size() > 1 ? typeString(collective.first()) + "s" : typeString(node);
-            text << Atom::ParaLeft << "These " << typeStr << " were introduced in "
-                 << formatSince(node) << "." << Atom::ParaRight;
-        } else {
-            text << Atom::ParaLeft << "This " << typeString(node) << " was introduced in "
-                 << formatSince(node) << "." << Atom::ParaRight;
-        }
+        text << Atom::ParaLeft << "This " << typeString(node) << " was introduced in "
+             << formatSince(node) << "." << Atom::ParaRight;
         generateText(text, node, marker);
     }
 }
@@ -1888,8 +1867,6 @@ void Generator::initializeFormat()
 
     if (s_outputFormats.isEmpty())
         return;
-    if (s_redirectDocumentationToDevNull)
-        return;
 
     s_outDir = config.getOutputDir(format());
     if (s_outDir.isEmpty()) {
@@ -2244,57 +2221,52 @@ QString Generator::typeString(const Node *node)
 {
     switch (node->nodeType()) {
     case NodeType::Namespace:
-        return "namespace"_L1;
+        return "namespace";
     case NodeType::Class:
-        return "class"_L1;
+        return "class";
     case NodeType::Struct:
-        return "struct"_L1;
+        return "struct";
     case NodeType::Union:
-        return "union"_L1;
+        return "union";
     case NodeType::QmlType:
     case NodeType::QmlValueType:
-        return "type"_L1;
+        return "type";
     case NodeType::Page:
-        return "documentation"_L1;
+        return "documentation";
     case NodeType::Enum:
-        return "enum"_L1;
+        return "enum";
     case NodeType::Typedef:
     case NodeType::TypeAlias:
-        return "typedef"_L1;
+        return "typedef";
     case NodeType::Function: {
         const auto fn = static_cast<const FunctionNode *>(node);
         switch (fn->metaness()) {
         case FunctionNode::QmlSignal:
-            return "signal"_L1;
+            return "signal";
         case FunctionNode::QmlSignalHandler:
-            return "signal handler"_L1;
+            return "signal handler";
         case FunctionNode::QmlMethod:
-            return "method"_L1;
+            return "method";
         case FunctionNode::MacroWithParams:
         case FunctionNode::MacroWithoutParams:
-            return "macro"_L1;
+            return "macro";
         default:
             break;
         }
-        return "function"_L1;
+        return "function";
     }
     case NodeType::Property:
     case NodeType::QmlProperty:
-        return "property"_L1;
+        return "property";
     case NodeType::Module:
     case NodeType::QmlModule:
-        return "module"_L1;
-    case NodeType::Variable:
-        return "variable"_L1;
+        return "module";
     case NodeType::SharedComment: {
-        const auto *shared = static_cast<const SharedCommentNode *>(node);
-        if (shared->isPropertyGroup())
-            return "property group"_L1;
-        const auto &collective = shared->collective();
+        const auto &collective = static_cast<const SharedCommentNode *>(node)->collective();
         return collective.first()->nodeTypeString();
     }
     default:
-        return "documentation"_L1;
+        return "documentation";
     }
 }
 
